@@ -7,7 +7,7 @@ This module implements the Search functionality of tmdbsimple.
 
 Created by Celia Oakley on 2013-10-31.
 
-:copyright: (c) 2013-2017 by Celia Oakley
+:copyright: (c) 2013-2018 by Celia Oakley
 :license: GPLv3, see LICENSE for more details
 """
 
@@ -17,7 +17,7 @@ class Search(TMDB):
     """
     Search functionality
 
-    See: http://docs.themoviedb.apiary.io/#search
+    See: https://developers.themoviedb.org/3/search
     """
     BASE_PATH = 'search'
     URLS = {
